@@ -141,11 +141,12 @@ class WindowSpecification(object):
                          'active': ('is_active',),
                          }
 
-    def __init__(self, search_criteria):
+    def __init__(self, search_criteria, allow_magic_lookup=True):
         """
         Initialize the class
 
         :param search_criteria: the criteria to match a dialog
+        :param allow_magic_lookup: whether attribute access must turn into child_window(best_match=...) search as fallback
         """
         # kwargs will contain however to find this window
         if 'backend' not in search_criteria:
@@ -158,6 +159,7 @@ class WindowSpecification(object):
         self.criteria = [search_criteria, ]
         self.actions = ActionLogger()
         self.backend = registry.backends[search_criteria['backend']]
+        self.allow_magic_lookup = allow_magic_lookup
 
         if self.backend.name == 'win32':
             # Non PEP-8 aliases for partial backward compatibility
@@ -173,7 +175,7 @@ class WindowSpecification(object):
             self.window_ = deprecated(self.child_window, deprecated_name='window_')
 
     def __call__(self, *args, **kwargs):
-        """No __call__ so return a usefull error"""
+        """No __call__ so return a useful error"""
         if "best_match" in self.criteria[-1]:
             raise AttributeError("Neither GUI element (wrapper) " \
                 "nor wrapper method '{0}' were found (typo?)".
@@ -182,8 +184,8 @@ class WindowSpecification(object):
         message = (
             "You tried to execute a function call on a WindowSpecification "
             "instance. You probably have a typo for one of the methods of "
-            "this class.\n"
-            "The criteria leading up to this is: " + str(self.criteria))
+            "this class or of the targeted wrapper object.\n"
+            "The criteria leading up to this are: " + str(self.criteria))
 
         raise AttributeError(message)
 
@@ -277,7 +279,7 @@ class WindowSpecification(object):
         if 'top_level_only' not in criteria:
             criteria['top_level_only'] = False
 
-        new_item = WindowSpecification(self.criteria[0])
+        new_item = WindowSpecification(self.criteria[0], allow_magic_lookup=self.allow_magic_lookup)
         new_item.criteria.extend(self.criteria[1:])
         new_item.criteria.append(criteria)
 
@@ -307,7 +309,7 @@ class WindowSpecification(object):
         """
         # if we already have 2 levels of criteria (dlg, control)
         # then resolve the control and do a getitem on it for the
-        if len(self.criteria) >= 2:
+        if len(self.criteria) >= 2:  # FIXME - this is surprising
 
             ctrls = self.__resolve_control(self.criteria)
 
@@ -324,7 +326,7 @@ class WindowSpecification(object):
 
         # if we get here then we must have only had one criteria so far
         # so create a new :class:`WindowSpecification` for this control
-        new_item = WindowSpecification(self.criteria[0])
+        new_item = WindowSpecification(self.criteria[0], allow_magic_lookup=self.allow_magic_lookup)
 
         # add our new criteria
         new_item.criteria.append({"best_match": key})
@@ -345,6 +347,21 @@ class WindowSpecification(object):
         Otherwise delegate functionality to :func:`__getitem__` - which
         sets the appropriate criteria for the control.
         """
+        allow_magic_lookup = object.__getattribute__(self, "allow_magic_lookup")  # Beware of recursions here!
+        if not allow_magic_lookup:
+            try:
+                return object.__getattribute__(self, attr_name)
+            except AttributeError:
+                wrapper_object = self.wrapper_object()
+                try:
+                    return getattr(wrapper_object, attr_name)
+                except AttributeError:
+                    message = (
+                        'Attribute "%s" exists neither on %s object nor on'
+                        'targeted %s element wrapper (typo? or set allow_magic_lookup to True?)' %
+                        (attr_name, self.__class__, wrapper_object.__class__))
+                    raise AttributeError(message)
+
         if attr_name in ['__dict__', '__members__', '__methods__', '__class__', '__name__']:
             return object.__getattribute__(self, attr_name)
 
@@ -354,10 +371,10 @@ class WindowSpecification(object):
         if attr_name in self.__dict__:
             return self.__dict__[attr_name]
 
-        # if we already have 2 levels of criteria (dlg, conrol)
+        # if we already have 2 levels of criteria (dlg, control)
         # this third must be an attribute so resolve and get the
         # attribute and return it
-        if len(self.criteria) >= 2:
+        if len(self.criteria) >= 2:  # FIXME - this is surprising
 
             ctrls = self.__resolve_control(self.criteria)
 
@@ -366,6 +383,7 @@ class WindowSpecification(object):
             except AttributeError:
                 return self.child_window(best_match=attr_name)
         else:
+            # FIXME - I don't get this part at all, why is it win32-specific and why not keep the same logic as above?
             # if we have been asked for an attribute of the dialog
             # then resolve the window and return the attribute
             desktop_wrapper = self.backend.generic_wrapper_class(self.backend.element_info_class())
@@ -870,7 +888,7 @@ class Application(object):
     .. automethod:: __getitem__
     """
 
-    def __init__(self, backend="win32", datafilename=None):
+    def __init__(self, backend="win32", datafilename=None, allow_magic_lookup=True):
         """
         Initialize the Application object
 
@@ -886,6 +904,7 @@ class Application(object):
         if backend not in registry.backends:
             raise ValueError('Backend "{0}" is not registered!'.format(backend))
         self.backend = registry.backends[backend]
+        self.allow_magic_lookup = allow_magic_lookup
         if self.backend.name == 'win32':
             # Non PEP-8 aliases for partial backward compatibility
             self.Start = deprecated(self.start)
@@ -1143,7 +1162,7 @@ class Application(object):
         else:
             criteria['title'] = windows[0].name
 
-        return WindowSpecification(criteria)
+        return WindowSpecification(criteria, allow_magic_lookup=self.allow_magic_lookup)
 
     def active(self):
         """Return WindowSpecification for an active window of the application"""
@@ -1167,7 +1186,7 @@ class Application(object):
         else:
             criteria['title'] = windows[0].name
 
-        return WindowSpecification(criteria)
+        return WindowSpecification(criteria, allow_magic_lookup=self.allow_magic_lookup)
 
     def windows(self, **kwargs):
         """Return a list of wrapped top level windows of the application"""
@@ -1209,7 +1228,7 @@ class Application(object):
         else:
             # add the restriction for this particular application
             kwargs['app'] = self
-            win_spec = WindowSpecification(kwargs)
+            win_spec = WindowSpecification(kwargs, allow_magic_lookup=self.allow_magic_lookup)
 
         return win_spec
     Window_ = window_ = window
@@ -1220,6 +1239,17 @@ class Application(object):
         return self.window(best_match=key)
 
     def __getattribute__(self, attr_name):
+        allow_magic_lookup = object.__getattribute__(self, "allow_magic_lookup")  # Beware of recursions here!
+        if not allow_magic_lookup:
+            try:
+                return object.__getattribute__(self, attr_name)
+            except AttributeError:
+                message = (
+                    'Attribute "%s" doesn\'t exist on %s object'
+                    ' (typo? or set allow_magic_lookup to True?)' %
+                    (attr_name, self.__class__))
+                raise AttributeError(message)
+
         """Find the specified dialog of the application"""
         if attr_name in ['__dict__', '__members__', '__methods__', '__class__']:
             return object.__getattribute__(self, attr_name)
